%solenoid
% Plots the magnetic field strength (and direction) of a solenoid
%
% LAST UPDATED by Andy French September 2016

function solenoid

%Number of current elements
M = 500;

%Length of solenoid
L = 0.1;

%Radius of solenoid
r = L;

%Number of helical wire coils or radius r
num_turns = 10;

%Compute coordinates of current elements
t=linspace(0,2*pi*num_turns,M);
xI = r*cos(t);
yI = linspace(-L/2,L/2,M);
zI = r*sin(t);

%Define current /square metre ('current density') at current element
%locations

%1 amp curent
I = 1;  

%Don't need exact values for J as it will be scaled. Only direction
%matters.
Jx = -sin(t);
Jz = cos(t);
Jy = zeros(1,M);

%Define limits for plot
xlimits = 3*L*[-1,1];
ylimits = 3*L*[-1,1];
zlimits = 3*L*[-1,1];
plot_title = 'Solenoid';

%Compute magnetic field
[Bx,By,Bz,x,y,z] = mfield( xI, yI,zI, Jx, Jy, Jz, I, xlimits, ylimits, zlimits, plot_title );

%End of code