%solenoid_ring
% Plots the magnetic field strength (and direction) of a solenoid ring
%
% LAST UPDATED by Andy French November 2016

function solenoid_ring

%Number of current elements
M = 1000;

%Length of solenoid
L = 0.1;

%Radius of solenoid
r = L;

%Radius of ring
R = 5*L;

%Determine coordinates of a straight solenoid ....

%Number of helical wire coils of radius r
N = 20;

%Compute coordinates of current elements
t=linspace(0,2*pi*N,M);
phi = t/N;
xI = ( R + r*cos(t) ).*cos(phi);
yI = ( R + r*cos(t) ).*sin(phi);
zI = r*sin(t);
%plot3(xI,yI,zI); axis equal; axis vis3d;

%Don't need exact values for J as it will be scaled. Only direction
%matters.
Jx = -sin(t).*cos(phi);
Jy = -sin(t).*cos(phi);
Jz = cos(t);

%Define limits for plot
xlimits = 2*R*[-1,1];
ylimits = 2*R*[-1,1];
zlimits = 2*R*[-1,1];
plot_title = 'Solenoid ring';

%Compute magnetic field
I = 1;
[Bx,By,Bz,x,y,z] = mfield( xI, yI,zI, Jx, Jy, Jz, I, xlimits, ylimits, zlimits, plot_title );

%End of code